@@ -4,7 +4,6 @@
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE RankNTypes #-}
 {-# LANGUAGE ScopedTypeVariables #-}
-{-# LANGUAGE Strict #-}
 {-# LANGUAGE TypeApplications #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE FlexibleInstances #-}
@@ -233,7 +232,7 @@ __Examples:__
 
 @
 > import qualified Data.Vector.Unboxed as V
-> fromVector (V.fromList [(1 :: Int), 2, 3, 4])
+> fromUnboxedVector (V.fromList [(1 :: Int), 2, 3, 4])
 [1,2,3,4]
 @
 -}
@@ -254,17 +253,19 @@ fromList ::
   => [a] -> Column
 fromList = toColumnRep @(KindOf a) . VB.fromList
 
-
+-- | Type-level boolean for constraint/type comparison.
 data SBool (b :: Bool) where
   STrue  :: SBool 'True
   SFalse :: SBool 'False
 
+-- | The runtime witness for our type-level branching.
 class SBoolI (b :: Bool) where
-  sbool :: SBool b          -- the run-time witness
+  sbool :: SBool b
 
 instance SBoolI 'True  where sbool = STrue
 instance SBoolI 'False where sbool = SFalse
 
+-- | Type-level function to determine whether or not a type is unboxa
 sUnbox :: forall a. SBoolI (Unboxable a) => SBool (Unboxable a)
 sUnbox = sbool @(Unboxable a)
 
@@ -377,6 +378,26 @@ getIndicesUnboxed :: (VU.Unbox a) => VU.Vector Int -> VU.Vector a -> VU.Vector a
 getIndicesUnboxed indices xs = VU.generate (VU.length indices) (\i -> xs VU.! (indices VU.! i))
 {-# INLINE getIndicesUnboxed #-}
 
+findIndices :: forall a. (Columnable a)
+            => (a -> Bool)
+            -> Column
+            -> Maybe (VU.Vector Int)
+findIndices pred (BoxedColumn (column :: VB.Vector b)) = do
+  Refl <- testEquality (typeRep @a) (typeRep @b)
+  pure $ VG.convert (VG.findIndices pred column)
+findIndices pred (UnboxedColumn (column :: VU.Vector b)) = do
+  Refl <- testEquality (typeRep @a) (typeRep @b)
+  pure $ VG.findIndices pred column
+findIndices pred (OptionalColumn (column :: VB.Vector (Maybe b))) = do
+  Refl <- testEquality (typeRep @a) (typeRep @(Maybe b))
+  pure $ VG.convert (VG.findIndices pred column)
+findIndices pred (GroupedBoxedColumn (column :: VB.Vector b)) = do
+  Refl <- testEquality (typeRep @a) (typeRep @b)
+  pure $ VG.convert (VG.findIndices pred column)
+findIndices pred (GroupedUnboxedColumn (column :: VB.Vector b)) = do
+  Refl <- testEquality (typeRep @a) (typeRep @b)
+  pure $ VG.convert (VG.findIndices pred column)
+
 -- | An internal function that returns a vector of how indexes change after a column is sorted.
 sortedIndexes :: Bool -> Column -> VU.Vector Int
 sortedIndexes asc (BoxedColumn column ) = runST $ do
@@ -564,27 +585,37 @@ freezeColumn' nulls (MutableUnboxedColumn col)
 
 -- | Fills the end of a column, up to n, with Nothing. Does nothing if column has length greater than n.
 expandColumn :: Int -> Column -> Column
-expandColumn n (OptionalColumn col) = OptionalColumn $ col <> VB.replicate n Nothing
+expandColumn n (OptionalColumn col) = OptionalColumn $ col <> VB.replicate (n - VG.length col) Nothing
 expandColumn n column@(BoxedColumn col)
-  | n < VG.length col = OptionalColumn $ VB.map Just col <> VB.replicate n Nothing
+  | n > VG.length col = OptionalColumn $ VB.map Just col <> VB.replicate (n - VG.length col) Nothing
   | otherwise         = column
 expandColumn n column@(UnboxedColumn col)
-  | n < VG.length col = OptionalColumn $ VB.map Just (VU.convert col) <> VB.replicate n Nothing
+  | n > VG.length col = OptionalColumn $ VB.map Just (VU.convert col) <> VB.replicate (n - VG.length col) Nothing
   | otherwise         = column
 expandColumn n column@(GroupedBoxedColumn col)
-  | n < VG.length col = GroupedBoxedColumn $ col <> VB.replicate n VB.empty
+  | n > VG.length col = GroupedBoxedColumn $ col <> VB.replicate (n - VG.length col) VB.empty
   | otherwise         = column
 expandColumn n column@(GroupedUnboxedColumn col)
-  | n < VG.length col = GroupedUnboxedColumn $ col <> VB.replicate n VU.empty
+  | n > VG.length col = GroupedUnboxedColumn $ col <> VB.replicate (n - VG.length col) VU.empty
   | otherwise         = column
 
 -- | Fills the beginning of a column, up to n, with Nothing. Does nothing if column has length greater than n.
 leftExpandColumn :: Int -> Column -> Column
-leftExpandColumn n (OptionalColumn col) = OptionalColumn $ VB.replicate n Nothing <> col
-leftExpandColumn n (BoxedColumn col) = OptionalColumn $ VB.replicate n Nothing <> VB.map Just col
-leftExpandColumn n (UnboxedColumn col) = OptionalColumn $ VB.replicate n Nothing <> VB.map Just (VU.convert col)
-leftExpandColumn n (GroupedBoxedColumn col) = GroupedBoxedColumn $ VB.replicate n VB.empty <> col
-leftExpandColumn n (GroupedUnboxedColumn col) = GroupedUnboxedColumn $ VB.replicate n VU.empty <> col
+leftExpandColumn n column@(OptionalColumn col)
+  | n > VG.length col = OptionalColumn $ VG.replicate (n - VG.length col) Nothing <> col
+  | otherwise         = column
+leftExpandColumn n column@(BoxedColumn col)
+  | n > VG.length col = OptionalColumn $ VG.replicate (n - VG.length col) Nothing <> VG.map Just col
+  | otherwise         = column
+leftExpandColumn n column@(UnboxedColumn col)
+  | n > VG.length col = OptionalColumn $ VG.replicate (n - VG.length col) Nothing <> VG.map Just (VU.convert col)
+  | otherwise         = column
+leftExpandColumn n column@(GroupedBoxedColumn col)
+  | n > VG.length col = GroupedBoxedColumn $ VG.replicate (n - VG.length col) VB.empty <> col
+  | otherwise         = column
+leftExpandColumn n column@(GroupedUnboxedColumn col)
+  | n > VG.length col = GroupedUnboxedColumn $ VG.replicate (n - VG.length col) VU.empty <> col
+  | otherwise         = column
 
 -- | Concatenates two columns.
 concatColumns :: Column -> Column -> Maybe Column
@@ -617,42 +648,44 @@ __Examples:__
 exception: ...
 -}
 toVector :: forall a . Columnable a => Column -> VB.Vector a
-toVector = toVectorWithLabel "toVector"
+toVector xs = case toVectorSafe xs of
+  Left err  -> throw err
+  Right val -> val
 
--- | An internal version of toVector that takes the calling function as an extra argument.
-toVectorWithLabel :: forall a . Columnable a => String -> Column -> VB.Vector a
-toVectorWithLabel label column@(OptionalColumn (col :: VB.Vector b)) =
+-- | A safe version of toVector that returns an Either type.
+toVectorSafe :: forall a . Columnable a => Column -> Either DataFrameException (VB.Vector a)
+toVectorSafe column@(OptionalColumn (col :: VB.Vector b)) =
   case testEquality (typeRep @a) (typeRep @b) of
-    Just Refl -> col
-    Nothing -> throw $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
-                                                               , expectedType = Right (typeRep @b)
-                                                               , callingFunctionName = Just label
-                                                               , errorColumnName = Nothing})
-toVectorWithLabel label (BoxedColumn (col :: VB.Vector b)) =
+    Just Refl -> Right col
+    Nothing -> Left $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
+                                                                 , expectedType = Right (typeRep @b)
+                                                                 , callingFunctionName = Just "toVectorSafe"
+                                                                 , errorColumnName = Nothing})
+toVectorSafe (BoxedColumn (col :: VB.Vector b)) =
   case testEquality (typeRep @a) (typeRep @b) of
-    Just Refl -> col
-    Nothing -> throw $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
-                                                               , expectedType = Right (typeRep @b)
-                                                               , callingFunctionName = Just label
-                                                               , errorColumnName = Nothing})
-toVectorWithLabel label (UnboxedColumn (col :: VU.Vector b)) =
+    Just Refl -> Right col
+    Nothing -> Left $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
+                                                                 , expectedType = Right (typeRep @b)
+                                                                 , callingFunctionName = Just "toVectorSafe"
+                                                                 , errorColumnName = Nothing})
+toVectorSafe (UnboxedColumn (col :: VU.Vector b)) =
   case testEquality (typeRep @a) (typeRep @b) of
-    Just Refl -> VB.convert col
-    Nothing -> throw $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
-                                                               , expectedType = Right (typeRep @b)
-                                                               , callingFunctionName = Just label
-                                                               , errorColumnName = Nothing})
-toVectorWithLabel label (GroupedBoxedColumn (col :: VB.Vector b)) =
+    Just Refl -> Right $ VB.convert col
+    Nothing -> Left $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
+                                                                 , expectedType = Right (typeRep @b)
+                                                                 , callingFunctionName = Just "toVectorSafe"
+                                                                 , errorColumnName = Nothing})
+toVectorSafe (GroupedBoxedColumn (col :: VB.Vector b)) =
   case testEquality (typeRep @a) (typeRep @b) of
-    Just Refl -> col
-    Nothing -> throw $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
-                                                               , expectedType = Right (typeRep @b)
-                                                               , callingFunctionName = Just label
-                                                               , errorColumnName = Nothing})
-toVectorWithLabel label (GroupedUnboxedColumn (col :: VB.Vector b)) =
+    Just Refl -> Right col
+    Nothing -> Left $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
+                                                                 , expectedType = Right (typeRep @b)
+                                                                 , callingFunctionName = Just "toVectorSafe"
+                                                                 , errorColumnName = Nothing})
+toVectorSafe (GroupedUnboxedColumn (col :: VB.Vector b)) =
   case testEquality (typeRep @a) (typeRep @b) of
-    Just Refl -> col
-    Nothing -> throw $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
-                                                               , expectedType = Right (typeRep @b)
-                                                               , callingFunctionName = Just label
-                                                               , errorColumnName = Nothing})
+    Just Refl -> Right col
+    Nothing -> Left $ TypeMismatchException (MkTypeErrorContext { userType = Right (typeRep @a)
+                                                                 , expectedType = Right (typeRep @b)
+                                                                 , callingFunctionName = Just "toVectorSafe"
+                                                                 , errorColumnName = Nothing})
